@@ -1,7 +1,5 @@
 from datetime import datetime
 
-from django.conf import settings
-
 FEEDZILLA_PAGE_SIZE = 25
 FEEDZILLA_SUMMARY_SIZE = 2000
 FEEDZILLA_SITE_TITLE = 'Yet another feedzilla site'
@@ -10,3 +8,7 @@ FEEDZILLA_HEAD_LINKS = ()
 FEEDZILLA_COPYRIGHTS = '%d &copy; Feedzilla Aggregator' % datetime.now().year
 FEEDZILLA_FEEDBURNER_FEED = None
 FEEDZILLA_FEEDBURNER_COUNTER = False
+FEEDZILLA_TWITTER = False
+FEEDZILLA_TWITTER_COUNTER = False
+FEEDZILLA_SUBMIT_SITE_BLOCK = True
+FEEDZILLA_TAG_CLOUD = True
